arrc.callbacks.histogram\_visualizer
====================================

.. automodule:: arrc.callbacks.histogram_visualizer

   
   .. rubric:: Classes

   .. autosummary::
   
      HistogramEmbeddingVisualizerCallback
   